@@ -468,9 +468,13 @@ END
 
  SHOW_OR_HIDE_TRACK => '<b>Show or hide this track</b>',
 
- KILL_THIS_TRACK    => '<b>Turn off this track.</b>',
+ KILL_THIS_TRACK    => '<b>Turn off this track</b>',
 
- CONFIGURE_THIS_TRACK   => '<b>Click to configure this track.</b>',
+ CONFIGURE_THIS_TRACK   => '<b>Configure this track</b>',
+
+ DOWNLOAD_THIS_TRACK   => '<b>Download this track</b>',
+
+ ABOUT_THIS_TRACK   => '<b>About this track</b>',
 
  SUBTRACKS_SHOWN    => 'This track contains selectable subtracks:',
 
