@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::TrackDumper;
 #
 ###################################################################
 
-# $Id: TrackDumper.pm 23222 2010-05-17 14:47:51Z lstein $
+# $Id: TrackDumper.pm 23246 2010-05-21 02:48:00Z lstein $
 
 # Simple track dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -137,9 +137,9 @@ sub dump_sam {
     my $header = $db->header;
 
     print $header->text;
-    print "\@C0\t$key\n";
-    print "\@C0\tGenerated by GBrowse from ",$self->origin($label),"\n";
-    print "\@C0\tSequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
+    print "\@CO\t$key\n";
+    print "\@CO\tGenerated by GBrowse from ",$self->origin($label),"\n";
+    print "\@CO\tSequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
 
     # there are problems with the filehandle-based conversion of 
     # BAM to TAM because the low-level functions write to STDOUT directly
